summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures
diff options
context:
space:
mode:
authorBrian Silver <bsilver@us.ibm.com>2016-09-30 11:56:28 -0500
committerChristian R. Geddes <crgeddes@us.ibm.com>2016-10-04 18:47:09 -0400
commit7bc64f60dbbfe24d3c7c0b649a94d1ca77cba86a (patch)
treed69467f9c321406726e73752a633bb0c622074ea /src/import/chips/p9/procedures
parentb54144d8e41c9fe494fe11d164e506194db90c44 (diff)
downloadtalos-hostboot-7bc64f60dbbfe24d3c7c0b649a94d1ca77cba86a.tar.gz
talos-hostboot-7bc64f60dbbfe24d3c7c0b649a94d1ca77cba86a.zip
Change memdiags end bounds for sf_read and bg scrub
sf_read defaults to stopping at the slave-rank boundary background scrub always stops immediate Change-Id: I8f687a403a988f0ad459e7a0e11ee1fed848b7ad Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/30566 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Zane C. Shelley <zshelle@us.ibm.com> Reviewed-by: ANDRE A. MARIN <aamarin@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/30571 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/procedures')
-rw-r--r--src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.C5
-rw-r--r--src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.H4
2 files changed, 5 insertions, 4 deletions
diff --git a/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.C b/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.C
index 96cc7e1cf..e9ab2b992 100644
--- a/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.C
+++ b/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.C
@@ -494,7 +494,8 @@ fapi_try_exit:
/// @param[in] i_speed the speed to scrub
/// @param[in] i_address mcbist::address representing the port, dimm, rank
/// @return FAPI2_RC_SUCCESS iff everything ok
-/// @note The function is asynchronous, and the caller should be looking for a done attention
+/// @warning The function is asynchronous, and the caller should be looking for a done attention
+/// @note The operation will fail immediately when a stop condition is encountered
///
template<>
fapi2::ReturnCode background_scrub( const fapi2::Target<TARGET_TYPE_MCBIST>& i_target,
@@ -505,7 +506,7 @@ fapi2::ReturnCode background_scrub( const fapi2::Target<TARGET_TYPE_MCBIST>& i_t
FAPI_INF("continuous (background) scrub");
fapi2::ReturnCode l_rc;
- constraints l_const(i_stop, i_speed, end_boundary::NONE, i_address);
+ constraints l_const(i_stop, i_speed, end_boundary::STOP_AFTER_ADDRESS, i_address);
continuous_scrub_operation<TARGET_TYPE_MCBIST> l_op(i_target, l_const, l_rc);
FAPI_ASSERT( l_rc == FAPI2_RC_SUCCESS,
diff --git a/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.H b/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.H
index 6b414a7df..5a6c26c01 100644
--- a/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.H
+++ b/src/import/chips/p9/procedures/hwp/memory/lib/mcbist/memdiags.H
@@ -322,14 +322,14 @@ fapi2::ReturnCode sf_init( const fapi2::Target<T>& i_target,
/// @note Uses broadcast mode if possible
/// @param[in] i_target the target behind which all memory should be read
/// @param[in] i_stop stop conditions
/// @param[in] i_end whether to end, and where - defaults to immediate (stop after failed address)
/// @return FAPI2_RC_SUCCESS iff everything ok
/// @note The function is asynchronous, and the caller should be looking for a done attention
///
template< fapi2::TargetType T >
fapi2::ReturnCode sf_read( const fapi2::Target<T>& i_target,
const stop_conditions& i_stop,
- const end_boundary i_end = end_boundary::STOP_AFTER_ADDRESS );
+ const end_boundary i_end = end_boundary::STOP_AFTER_SLAVE_RANK );
///
/// @brief Super Fast Read to End of Port - used to run superfast read on all memory behind the target
OpenPOWER on IntegriCloud
@@ -322,14 +322,14 @@ fapi2::ReturnCode sf_init( const fapi2::Target<T>& i_target,
/// @param[in] i_target the target behind which all memory should be read
/// @param[in] i_stop stop conditions
-/// @param[in] i_end whether to end, and where - defaults to immediate (stop after failed address)
+/// @param[in] i_end whether to end, and where - defaults to stop after slave rank
/// @return FAPI2_RC_SUCCESS iff everything ok
/// @note The function is asynchronous, and the caller should be looking for a done attention